headers = [\
{
   "HTTP_X_WAP_PROFILE": "\"http://nds1.nds.nokia.com/uaprof/NX2-00r100.xml\", \"1-4xx28zdY1/BbVIZPpYDH/A==\", \"2-XnrTOLDzBJdZHN2vSasoNA==\", \"3-HC5l5j+eQ9tPRpdhsseJIQ==\"",
   "HTTP_COOKIE": "Bearer-Type=w-TCP;wtls-security-level=none;network-access-type=CSD",
   "SERVER_SOFTWARE": "Apache/2.2.17 (Ubuntu)",
   "SCRIPT_NAME": "",
   "QUERY_STRING": "code=dddfb329-9124-4e56-b02f-b430b0716de8&email=talk2femi09%40yahoo.com",
   "HTTP_X_WAP_PROFILE_DIFF": "1; <?xml version=\"1.0\"?><rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\" xmlns:prf=\"http://www.wapforum.org/UAPROF/ccppschema-19991014#\"><!-- browser vendor site: Default description of properties --><rdf:Description><prf:CcppAccept><rdf:Bag><rdf:li>application/vnd.wap.wmlscriptc</rdf:li><rdf:li>text/vnd.wap.wml</rdf:li><rdf:li>application/vnd.wap.xhtml+xml</rdf:li><rdf:li>application/xhtml+xml</rdf:li><rdf:li>text/xml</rdf:li><rdf:li>text/html</rdf:li><rdf:li>text/css</rdf:li><rdf:li>multipart/mixed</rdf:li><rdf:li>*/*</rdf:li><rdf:li>text/vnd.wap.wmlscript</rdf:li></rdf:Bag></prf:CcppAccept></rdf:Description></rdf:RDF>",
   "PATH_INFO": "/",
   "SERVER_PROTOCOL": "HTTP/1.1",
   "HTTP_X_NOKIA_MUSICSHOP_BEARER": "GPRS/3G",
   "HTTP_X_FORWARDED_PORT": "80",
   "HTTP_ACCEPT_CHARSET": "*",
   "HTTP_USER_AGENT": "NokiaX2-00/5.0 (04.90) Profile/MIDP-2.1 Configuration/CLDC-1.1 Mozilla/5.0 AppleWebKit/420+ (KHTML, like Gecko) Safari/420+",
   "HTTP_CONNECTION": "keep-alive",
   "SERVER_NAME": "example.com",
   "REMOTE_ADDR": "10.210.247.150",
   "HTTP_X_NOKIA_MUSICSHOP_VERSION": "1.2.1",
   "SERVER_PORT": "80",
   "SERVER_ADDR": "10.72.87.133",
   "remote_ip": "41.206.15.18",
   "format": "application/vnd.wap.xhtml+xml",
   "HTTP_X_FORWARDED_PROTO": "http",
   "SERVER_ADMIN": "[no address given]",
   "SCRIPT_URI": "http://example.com/",
   "HTTP_DRM_VERSION": "2.0",
   "HTTP_HOST": "example.com",
   "SCRIPT_URL": "/",
   "HTTP_COOKIE2": "$Version=\"1\"",
   "REQUEST_URI": "/?code=dddfb329-9124-4e56-b02f-b430b0716de8&email=talk2femi09%40yahoo.com",
   "HTTP_ACCEPT": "application/vnd.wap.wmlscriptc, text/vnd.wap.wml, application/vnd.wap.xhtml+xml, application/xhtml+xml, text/xml, text/html, text/css, multipart/mixed, */*, text/vnd.wap.wmlscript",
   "HTTP_WAP_CONNECTION": "Stack-Type=HTTP",
   "url": "http://example.com/?code=dddfb329-9124-4e56-b02f-b430b0716de8&email=talk2femi09%40yahoo.com",
   "REMOTE_PORT": "41180",
   "HTTP_ACCEPT_LANGUAGE": "en",
   "HTTP_X_FORWARDED_FOR": "41.206.15.18",
   "HTTP_X_REQUEST_START": "t=1313615637103298",
   "REQUEST_METHOD": "GET",
   "DOCUMENT_ROOT": "/var/www"
},
{
   "HTTP_REFERER": "http://example.com/",
   "SERVER_SOFTWARE": "Apache/2.2.17 (Ubuntu)",
   "SCRIPT_NAME": "",
   "HTTP_X_FORWARDED_PORT": "80",
   "PATH_INFO": "/",
   "SERVER_PROTOCOL": "HTTP/1.1",
   "QUERY_STRING": "",
   "HTTP_ACCEPT_CHARSET": "iso-8859-1, utf-8, utf-16, *;q=0.1",
   "HTTP_USER_AGENT": "Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.14881/25.729; U; en) Presto/2.5.25 Version/10.54",
   "HTTP_CONNECTION": "keep-alive",
   "HTTP_COOKIE": "_Members_session=BAh7BiIPc2Vzc2lvbl9pZCIlZTA1NDY4YjFjYTZiMDczMTAzM2U4MWYwYzhmNzZjNDI%3D--f5a7a61676e61cf449d83e3d6c3e0e12b5364917",
   "SERVER_NAME": "example.com",
   "HTTP_X_OPERAMINI_PHONE_UA": "NokiaX2-00",
   "SERVER_PORT": "80",
   "SERVER_ADDR": "10.72.11.51",
   "remote_ip": "41.206.15.18",
   "REMOTE_PORT": "15897",
   "format": "text/html",
   "HTTP_X_FORWARDED_PROTO": "http",
   "SERVER_ADMIN": "[no address given]",
   "SCRIPT_URI": "http://example.com/",
   "HTTP_HOST": "example.com",
   "SCRIPT_URL": "/",
   "HTTP_X_OPERAMINI_FEATURES": "advanced, file_system, folding",
   "HTTP_COOKIE2": "$Version=1",
   "REQUEST_URI": "/",
   "HTTP_ACCEPT": "text/html, application/xml;q=0.9, application/xhtml+xml, image/png, image/jpeg, image/gif, image/x-xbitmap, */*;q=0.1",
   "HTTP_X_OPERAMINI_PHONE": "Nokia # X2-00",
   "url": "http://example.com/",
   "REMOTE_ADDR": "10.210.247.150",
   "HTTP_ACCEPT_LANGUAGE": "en",
   "HTTP_X_FORWARDED_FOR": "41.206.15.18, 82.145.210.98",
   "HTTP_X_REQUEST_START": "t=1313615754667339",
   "REQUEST_METHOD": "GET",
   "DOCUMENT_ROOT": "/var/www/",
   "HTTP_ACCEPT_ENCODING": "deflate, gzip, x-gzip, identity, *;q=0"
},
{
   "HTTP_REFERER": "http://gowaping.com/site_90.xhtml?get-id=738",
   "SERVER_SOFTWARE": "Apache/2.2.17 (Ubuntu)",
   "SCRIPT_NAME": "",
   "HTTP_X_FORWARDED_PORT": "80",
   "PATH_INFO": "/",
   "SERVER_PROTOCOL": "HTTP/1.1",
   "QUERY_STRING": "cid=BC_NG_ATS3_EN_0",
   "HTTP_ACCEPT_CHARSET": "iso-8859-1, utf-8; q=0.7, *; q=0.7",
   "HTTP_USER_AGENT": "Mozilla/5.0 (SymbianOS/9.1; U; [en]; SymbianOS/9.1 Series60/3.0) AppleWebKit/413 (KHTML, like Gecko) Safari/413",
   "HTTP_CONNECTION": "keep-alive",
   "SERVER_NAME": "example.com",
   "REMOTE_ADDR": "10.210.247.150",
   "SERVER_PORT": "80",
   "REQUEST_URI": "/?cid=BC_NG_ATS3_EN_0",
   "SERVER_ADDR": "10.240.110.124",
   "remote_ip": "41.190.3.221",
   "format": "text/html",
   "HTTP_X_FORWARDED_PROTO": "http",
   "SERVER_ADMIN": "[no address given]",
   "SCRIPT_URI": "http://example.com/",
   "HTTP_HOST": "example.com",
   "SCRIPT_URL": "/",
   "HTTP_ACCEPT": "text/html,application/xhtml+xml,text/css, */*",
   "url": "http://example.com/?cid=BC_NG_ATS3_EN_0",
   "REMOTE_PORT": "22566",
   "HTTP_ACCEPT_LANGUAGE": "en;q=1.0,ar;q=0.5,fr;q=0.5,de;q=0.5,es;q=0.5,it;q=0.5",
   "HTTP_X_FORWARDED_FOR": "41.190.3.221",
   "HTTP_X_REQUEST_START": "t=1313616134527736",
   "REQUEST_METHOD": "GET",
   "DOCUMENT_ROOT": "/var/www/",
   "HTTP_ACCEPT_ENCODING": "gzip, deflate, x-gzip, identity; q=0.9"
},
{
   "HTTP_X_WAP_PROFILE": "\"http://www.htcmms.com.tw/gen/Herald-1.0.xml\"",
   "HTTP_REFERER": "http://ad.mosko.mobi/",
   "SERVER_SOFTWARE": "Apache/2.2.17 (Ubuntu)",
   "SCRIPT_NAME": "",
   "HTTP_X_FORWARDED_PORT": "80",
   "PATH_INFO": "/",
   "SERVER_PROTOCOL": "HTTP/1.1",
   "QUERY_STRING": "cid=BC_NG_ATS3_EN_0",
   "HTTP_UA_COLOR": "color16",
   "HTTP_USER_AGENT": "Mozilla/4.0 (compatible; MSIE 6.0; Windows CE; PPC)",
   "HTTP_CONNECTION": "keep-alive",
   "SERVER_NAME": "example.com",
   "REMOTE_ADDR": "10.210.247.150",
   "SERVER_PORT": "80",
   "REQUEST_URI": "/?cid=BC_NG_ATS3_EN_0",
   "SERVER_ADDR": "10.72.11.51",
   "remote_ip": "41.206.11.37",
   "HTTP_UA_OS": "Windows CE (Pocket PC) - Version 5.2",
   "format": "application/vnd.wap.xhtml+xml",
   "HTTP_X_FORWARDED_PROTO": "http",
   "SERVER_ADMIN": "[no address given]",
   "SCRIPT_URI": "http://example.com/",
   "HTTP_HOST": "example.com",
   "SCRIPT_URL": "/",
   "HTTP_UA_CPU": "ARM",
   "HTTP_ACCEPT": "*/*",
   "url": "http://example.com/?cid=BC_NG_ATS3_EN_0",
   "REMOTE_PORT": "16884",
   "HTTP_ACCEPT_LANGUAGE": "en-us",
   "HTTP_UA_VOICE": "TRUE",
   "HTTP_UA_PIXELS": "320x240",
   "HTTP_X_REQUEST_START": "t=1313615865674202",
   "REQUEST_METHOD": "GET",
   "HTTP_X_FORWARDED_FOR": "41.206.11.37",
   "DOCUMENT_ROOT": "/var/www/",
   "HTTP_ACCEPT_ENCODING": "gzip,deflate"
}
]
