{% extends "base.html" %}
{% load url from future %}
{% load xray_tags %}

{% block extra_stylesheets %}
  <link href="//netdna.bootstrapcdn.com/font-awesome/3.2.1/css/font-awesome.css" rel="stylesheet">
  <link type="text/css" rel="stylesheet" href="{{ STATIC_URL }}xray/stylesheets/xray.css" />
{% endblock extra_stylesheets %}

{% block title %}RapidSMS X-ray{% endblock title %}
{% block content %}
    <div class="page-header"><h1>RapidSMS X-ray</h1></div>
      <div class="span5 stats relief">
	<a href="{% url 'xray_experiments' %}">
	<h3>Experiments</h3>
	<ul>
          <li>
	  <span class="pic"><i class="{{ web_xray_dashboard_experiments_icon_variant }} icon-3x"></i></span><span class="value">{{ experiments }}</span> <span class="caption">experiments</span>
          </li>
	</ul>
        </a>
      </div>
      <div class="span5 stats relief">
	<a href="{% url 'xray_events' %}">
	<h3>Events</h3>
	<ul>
	  <li>
	  <span class="pic"><i class="{{ web_xray_dashboard_web_icon_variant }} icon-3x"></i></span><span class="value">{{ web_active }}</span> <span class="caption">active web users this week</span>
          </li>
	  <li>
	  <span class="pic"><i class="{{ web_xray_dashboard_phone_icon_variant }} icon-3x"></i></span><span class="value">{{ sms_active }}</span> <span class="caption">active sms users this week</span>
          </li>
	</ul>
        </a>
     </div>
{% endblock content %}
